Coverage for gramex\handlers\__init__.py: 89%

# Coverage for gramex\handlers\__init__.py : 89%

## 25 statements 23 run 2 missing 0 excluded 1 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1'''

2 Handlers

3'''

4

5 from .basehandler import BaseHandler, BaseWebSocketHandler, SetupFailedHandler

6 from .functionhandler import FunctionHandler

7 from .websockethandler import WebSocketHandler

8 from .filehandler import FileHandler

9 from .authhandler import GoogleAuth, SimpleAuth, LogoutHandler

10 from .processhandler import ProcessHandler

11 from .jsonhandler import JSONHandler

12 from .socialhandler import TwitterRESTHandler, FacebookGraphHandler

13 from .uploadhandler import UploadHandler

14 from .capturehandler import CaptureHandler, Capture

15 from .formhandler import FormHandler

16 from .pptxhandler import PPTXHandler

17 from .proxyhandler import ProxyHandler

18 from .modelhandler import ModelHandler

19 from .filterhandler import FilterHandler

20 from .drivehandler import DriveHandler

21

22 DirectoryHandler = FileHandler

23

24 __all__ = [

25 'BaseHandler',

26 'BaseWebSocketHandler',

27 'Capture',

28 'CaptureHandler',

29 'DirectoryHandler',

30 'DriveHandler',

31 'FacebookGraphHandler',

32 'FileHandler',

33 'FilterHandler',

34 'FormHandler',

35 'FunctionHandler',

36 'GoogleAuth',

37 'JSONHandler',

38 'LogoutHandler',

39 'ModelHandler',

40 'PPTXHandler',

41 'ProcessHandler',

42 'ProxyHandler',

43 'SetupFailedHandler',

44 'SimpleAuth',

45 'TwitterRESTHandler',

46 'UploadHandler',

47 'WebSocketHandler',

48]

49

50 try:

51 # If Gramex enterprise is available, import all handlers

52 import gramexenterprise.handlers

53 if hasattr(gramexenterprise, 'handlers'): 53 ↛ exitline 53 didn't jump to the function exit

54 from gramexenterprise.handlers import * # noqa

55 __all__ += gramexenterprise.handlers.__all__

56 except ImportError:

57 pass